==> dataCompare_1.0.1.tar.gz: dataCompare/R/dataCompare-package.R <==
#' @keywords internal
"_PACKAGE"

utils::globalVariables(c(".", "rv", 'Variable', 'Type', 'numeric.mean', 'statistic', 'value',
                         'skim_variable', 'skim_type', 'complete_rate', 'numeric.hist'))

## usethis namespace: start
#' @importFrom data.table month
#' @importFrom devtools document
#' @importFrom dplyr between
#' @importFrom dplyr case_when
#' @importFrom dplyr ends_with
#' @importFrom dplyr filter
#' @importFrom dplyr inner_join
#' @importFrom dplyr select
#' @importFrom dplyr ungroup
#' @importFrom DT datatable
#' @importFrom DT JS
#' @importFrom golem add_resource_path
#' @importFrom htmltools a
#' @importFrom htmltools br
#' @importFrom htmltools img
#' @importFrom htmltools p
#' @importFrom htmltools strong
#' @importFrom htmltools tagList
#' @importFrom htmltools tags
#' @importFrom lubridate hour
#' @importFrom pins pin
#' @importFrom shiny actionButton
#' @importFrom shiny callModule
#' @importFrom shiny column
#' @importFrom shiny fileInput
#' @importFrom shiny fluidRow
#' @importFrom shiny icon
#' @importFrom shiny NS
#' @importFrom shiny observeEvent
#' @importFrom shiny reactive
#' @importFrom shiny reactiveValues
#' @importFrom shiny renderUI
#' @importFrom shiny req
#' @importFrom shiny shinyApp
#' @importFrom shiny span
#' @importFrom shiny uiOutput
#' @importFrom shiny validate
#' @importFrom shinydashboard box
#' @importFrom shinydashboard dashboardBody
#' @importFrom shinydashboard menuItem
#' @importFrom shinydashboard renderValueBox
#' @importFrom shinydashboard sidebarMenu
#' @importFrom shinydashboard tabItem
#' @importFrom shinydashboard tabItems
#' @importFrom shinydashboard valueBox
#' @importFrom shinydashboard valueBoxOutput
#' @importFrom shinydashboardPlus dashboardFooter
#' @importFrom shinydashboardPlus dashboardHeader
#' @importFrom shinydashboardPlus dashboardPage
#' @importFrom shinydashboardPlus dashboardSidebar
#' @importFrom shinyjs alert
#' @importFrom shinyWidgets actionBttn
#' @importFrom shinyWidgets radioGroupButtons
#' @importFrom skimr skim
#' @importFrom utils read.csv2
#' @importFrom utils read.table
#' @importFrom vroom spec
## usethis namespace: end
NULL

==> dataCompare_1.0.5.tar.gz: dataCompare/R/dataCompare-package.R <==
#' @keywords internal
"_PACKAGE"

utils::globalVariables(c(".", "rv", 'Variable', 'Type', 'numeric.mean', 'statistic', 'value',
                         'skim_variable', 'skim_type', 'complete_rate', 'numeric.hist'))

## usethis namespace: start
#' @importFrom data.table month
#' @importFrom devtools document
#' @importFrom dplyr between
#' @importFrom dplyr case_when
#' @importFrom dplyr ends_with
#' @importFrom dplyr filter
#' @importFrom dplyr inner_join
#' @importFrom dplyr select
#' @importFrom dplyr ungroup
#' @importFrom DT datatable
#' @importFrom DT JS
#' @importFrom explore describe
#' @importFrom golem add_resource_path
#' @importFrom htmltools a
#' @importFrom htmltools br
#' @importFrom htmltools img
#' @importFrom htmltools p
#' @importFrom htmltools strong
#' @importFrom htmltools tagList
#' @importFrom htmltools tags
#' @importFrom shiny actionButton
#' @importFrom shiny callModule
#' @importFrom shiny column
#' @importFrom shiny fileInput
#' @importFrom shiny fluidRow
#' @importFrom shiny icon
#' @importFrom shiny NS
#' @importFrom shiny observeEvent
#' @importFrom shiny reactive
#' @importFrom shiny reactiveValues
#' @importFrom shiny renderUI
#' @importFrom shiny req
#' @importFrom shiny shinyApp
#' @importFrom shiny span
#' @importFrom shiny uiOutput
#' @importFrom shiny validate
#' @importFrom shinycssloaders hidePageSpinner
#' @importFrom shinycssloaders showPageSpinner
#' @importFrom shinycssloaders withSpinner
#' @importFrom shinydashboard box
#' @importFrom shinydashboard dashboardBody
#' @importFrom shinydashboard menuItem
#' @importFrom shinydashboard renderValueBox
#' @importFrom shinydashboard sidebarMenu
#' @importFrom shinydashboard tabItem
#' @importFrom shinydashboard tabItems
#' @importFrom shinydashboard valueBox
#' @importFrom shinydashboard valueBoxOutput
#' @importFrom shinydashboardPlus dashboardFooter
#' @importFrom shinydashboardPlus dashboardHeader
#' @importFrom shinydashboardPlus dashboardPage
#' @importFrom shinydashboardPlus dashboardSidebar
#' @importFrom shinyWidgets actionBttn
#' @importFrom shinyWidgets radioGroupButtons
#' @importFrom skimr skim
#' @importFrom utils read.csv2
#' @importFrom utils read.table
## usethis namespace: end
NULL
